<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package customfolio
 * @since customfolio 1.6
 */
?><!DOCTYPE html>
<!--[if IE 8]>
<html id="ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 8) ]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<meta name="viewport" content="width=device-width" />
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'customfolio' ), max( $paged, $page ) );

	?></title>
<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php do_action( 'before' ); ?>

	<header id="masthead" class="site-header" role="banner">
		<div class="header-wrapper">
			<hgroup>
				<h1 class="site-title"><a href="<?php echo home_url( '/' ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
			</hgroup>
			

			<nav role="navigation" class="site-navigation main-navigation">
				<h1 class="assistive-text"><?php _e( 'Menu', 'customfolio' ); ?></h1>
				<div class="assistive-text skip-link"><a href="#content" title="<?php esc_attr_e( 'Skip to content', 'customfolio' ); ?>"><?php _e( 'Skip to content', 'customfolio' ); ?></a></div>
				<?php wp_nav_menu( array( 'theme_location' => 'primary' ) ); ?>
			</nav>


		</div><!-- .header-wrapper -->
	</header><!-- .site-header -->


		<?php // Loads homepage templates and slider selection
		if ( is_page_template( 'page-showcase.php' ) || is_page_template( 'page-showcase-alt.php' )  ) : ?>

		<?php get_template_part( 'featured-content' ); ?>

		<?php else : ?>
		<section class="title-wrapper">
				<?php if(is_single() || is_page() || is_home()) { ?>
				<h1 class="entry-title"><?php single_post_title();  ?></h1>
				<?php } elseif (  is_category() ) { ?>
				<h1 class="entry-title"><?php printf( __( 'Category Archives: %s', 'customfolio' ), '<span>' . single_cat_title( '', false ) . '</span>' ); ?></h1>
				<?php } elseif ( is_tag() ) { ?>
				<h1 class="entry-title"><?php printf( __( 'Tag Archives: %s', 'customfolio' ), '<span>' . single_tag_title( '', false ) . '</span>' ); ?></h1>
				<?php } elseif ( is_author() ) { ?>
				<h1 class="entry-title">Author Archives</h1>
				<?php } elseif ( is_day() ) { ?>
				<h1 class="entry-title"><?php printf( __( 'Daily Archives: %s', 'customfolio' ), '<span>' . get_the_date() . '</span>' ); ?></h1>
				<?php } elseif ( is_month() ) { ?>
				<h1 class="entry-title"><?php printf( __( 'Monthly Archives: %s', 'customfolio' ), '<span>' . get_the_date( 'F Y' ) . '</span>' ); ?></h1>
				<?php } elseif ( is_year() ) { ?>
				<h1 class="entry-title"><?php printf( __( 'Yearly Archives: %s', 'customfolio' ), '<span>' . get_the_date( 'Y' ) . '</span>' ); ?></h1>
				<?php } elseif ( is_search() ) { ?>
				<h1 class="entry-title"><?php printf( __( 'Search Results for: %s', 'customfolio' ), '<span>' . get_search_query() . '</span>' ); ?></h1>
				<?php } elseif ( is_404() ) { ?>
				<h1 class="entry-title">Oops! That page can&rsquo;t be found.</h1>
				<?php } ?>
		</section><!-- .entry-header -->
		<?php endif ?>
		
		
	<div id="page" class="hfeed site">
	<div id="main">